==> theremin_1.8.1-1.tar.gz: theremin-1.8.1/src/KeyboardWindow.hpp <==
/* The MIT License:

Copyright (c) 2009 Ivan Gagis

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE. */

#pragma once


#include <gtkmm/menu.h>
#include <gtkmm/drawingarea.h>

#include <ting/types.hpp>
#include <ting/Fixed.hpp>
#include <aumiks/synth/synth.hpp>

#include "BasicWindow.hpp"
#include "utils.hpp"
#include "Preferences.hpp"



class KeyboardWindow : public BasicWindow{
#ifdef M_USE_FIXED_POINT
	typedef ting::Fixed<16> real;
#else
	typedef float real;
#endif

	MonotonicInstrumentHolder instr;

	ting::uint curKeyOffset;


	class KeyboardView : public Gtk::DrawingArea{
	public:
		KeyboardView();

		bool OnExposeEvent(GdkEventExpose* event);

		static void DrawOctave(Cairo::RefPtr<Cairo::Context> c, ting::uint w, ting::uint h, ting::uint basePitch);
	};

public:
	KeyboardWindow();
	~KeyboardWindow(){
//		TRACE(<< "~ThereminView(): invoked" << std::endl)
	}

	void OnShow();

	bool OnButtonPressEvent(GdkEventButton* event);
	bool OnButtonReleaseEvent(GdkEventButton* event);
	bool OnMotionEvent(GdkEventMotion* event);
	void OnKeyPress_Notify(GdkEventKey* event);

	void ShowOptionsDialog();

	struct FreqVol{
		real freq;
		ting::u8 vol;
		ting::uint keyNumber;
	};


	ting::uint CalcKeyOffset(real scrW, real scrH, real tapX, real tapY);

	//if isPressEvent is true then this->curOctave will be updated,
	//otherwise the old value will be used
	FreqVol CalcFreqAndVol(real scrW, real scrH, real tapX, real tapY);
};

==> theremin_1.8.1-3.tar.gz: theremin-1.8.1/src/KeyboardWindow.hpp <==
/* The MIT License:

Copyright (c) 2009-2010 Ivan Gagis

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE. */

#pragma once


#include <gtkmm/menu.h>
#include <gtkmm/drawingarea.h>

#include <ting/types.hpp>
#include <aumiks/synth/synth.hpp>

#include "Fixed.hpp"

#include "BasicWindow.hpp"
#include "utils.hpp"
#include "Preferences.hpp"



class KeyboardWindow : public BasicWindow{
#ifdef M_USE_FIXED_POINT
	typedef ting::Fixed<16> real;
#else
	typedef float real;
#endif

	MonotonicInstrumentHolder instr;

	unsigned curKeyOffset;


	class KeyboardView : public Gtk::DrawingArea{
	public:
		KeyboardView();

		bool OnExposeEvent(GdkEventExpose* event);

		static void DrawOctave(Cairo::RefPtr<Cairo::Context> c, unsigned w, unsigned h, unsigned basePitch);
	};

public:
	KeyboardWindow();
	~KeyboardWindow(){
//		TRACE(<< "~ThereminView(): invoked" << std::endl)
	}

	void OnShow();

	bool OnButtonPressEvent(GdkEventButton* event);
	bool OnButtonReleaseEvent(GdkEventButton* event);
	bool OnMotionEvent(GdkEventMotion* event);
	void OnKeyPress_Notify(GdkEventKey* event);

	void ShowOptionsDialog();

	struct FreqVol{
		real freq;
		ting::u8 vol;
		unsigned keyNumber;
	};


	unsigned CalcKeyOffset(real scrW, real scrH, real tapX, real tapY);

	//if isPressEvent is true then this->curOctave will be updated,
	//otherwise the old value will be used
	FreqVol CalcFreqAndVol(real scrW, real scrH, real tapX, real tapY);
};
